@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt SVG module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -60,6 +52,7 @@
 #include "QtGui/qcolor.h"
 #include "QtGui/qfont.h"
 #include <qdebug.h>
+#include "qtsvgglobal_p.h"
 
 QT_BEGIN_NAMESPACE
 
@@ -115,7 +108,7 @@ private:
     T *t;
 };
 
-class QSvgRefCounted
+class Q_SVG_PRIVATE_EXPORT QSvgRefCounted
 {
 public:
     QSvgRefCounted() { _ref = 0; }
@@ -135,7 +128,7 @@ private:
     int _ref;
 };
 
-struct QSvgExtraStates
+struct Q_SVG_PRIVATE_EXPORT QSvgExtraStates
 {
     QSvgExtraStates();
 
@@ -149,7 +142,7 @@ struct QSvgExtraStates
     bool vectorEffect; // true if pen is cosmetic
 };
 
-class QSvgStyleProperty : public QSvgRefCounted
+class Q_SVG_PRIVATE_EXPORT QSvgStyleProperty : public QSvgRefCounted
 {
 public:
     enum Type
@@ -174,7 +167,7 @@ public:
     virtual Type type() const=0;
 };
 
-class QSvgFillStyleProperty : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgFillStyleProperty : public QSvgStyleProperty
 {
 public:
     virtual QBrush brush(QPainter *p, QSvgExtraStates &states) = 0;
@@ -182,7 +175,7 @@ public:
     virtual void revert(QPainter *p, QSvgExtraStates &states);
 };
 
-class QSvgQualityStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgQualityStyle : public QSvgStyleProperty
 {
 public:
     QSvgQualityStyle(int color);
@@ -214,7 +207,7 @@ private:
 
 
 
-class QSvgOpacityStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgOpacityStyle : public QSvgStyleProperty
 {
 public:
     QSvgOpacityStyle(qreal opacity);
@@ -226,7 +219,7 @@ private:
     qreal m_oldOpacity;
 };
 
-class QSvgFillStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgFillStyle : public QSvgStyleProperty
 {
 public:
     QSvgFillStyle();
@@ -299,7 +292,7 @@ private:
     uint m_fillSet : 1;
 };
 
-class QSvgViewportFillStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgViewportFillStyle : public QSvgStyleProperty
 {
 public:
     QSvgViewportFillStyle(const QBrush &brush);
@@ -319,7 +312,7 @@ private:
     QBrush m_oldFill;
 };
 
-class QSvgFontStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgFontStyle : public QSvgStyleProperty
 {
 public:
     static const int LIGHTER = -1;
@@ -403,7 +396,7 @@ private:
     uint m_textAnchorSet : 1;
 };
 
-class QSvgStrokeStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgStrokeStyle : public QSvgStyleProperty
 {
 public:
     QSvgStrokeStyle();
@@ -543,7 +536,7 @@ private:
     uint m_vectorEffectSet : 1;
 };
 
-class QSvgSolidColorStyle : public QSvgFillStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgSolidColorStyle : public QSvgFillStyleProperty
 {
 public:
     QSvgSolidColorStyle(const QColor &color);
@@ -568,7 +561,7 @@ private:
     QPen   m_oldStroke;
 };
 
-class QSvgGradientStyle : public QSvgFillStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgGradientStyle : public QSvgFillStyleProperty
 {
 public:
     QSvgGradientStyle(QGradient *grad);
@@ -610,7 +603,7 @@ private:
     bool m_gradientStopsSet;
 };
 
-class QSvgTransformStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgTransformStyle : public QSvgStyleProperty
 {
 public:
     QSvgTransformStyle(const QTransform &transform);
@@ -629,7 +622,7 @@ private:
 };
 
 
-class QSvgAnimateTransform : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgAnimateTransform : public QSvgStyleProperty
 {
 public:
     enum TransformType
@@ -702,7 +695,7 @@ private:
 };
 
 
-class QSvgAnimateColor : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgAnimateColor : public QSvgStyleProperty
 {
 public:
     QSvgAnimateColor(int startMs, int endMs, int by = 0);
@@ -725,7 +718,7 @@ private:
 };
 
 
-class QSvgCompOpStyle : public QSvgStyleProperty
+class Q_SVG_PRIVATE_EXPORT QSvgCompOpStyle : public QSvgStyleProperty
 {
 public:
     QSvgCompOpStyle(QPainter::CompositionMode mode);
@@ -745,7 +738,7 @@ private:
 };
 
 
-class QSvgStyle
+class Q_SVG_PRIVATE_EXPORT QSvgStyle
 {
 public:
     QSvgStyle()
